"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apply = exports.Config = exports.usage = exports.name = void 0;
const koishi_1 = require("koishi");
exports.name = 'github-og';
exports.usage = `
## 响应的消息格式
* koishijs/koishi
* https://github.com/koishijs/koishi
`;
exports.Config = koishi_1.Schema.object({});
async function digest(message) {
    const msgUint8 = new TextEncoder().encode(message);
    const hashBuffer = await crypto.subtle.digest('SHA-256', msgUint8);
    const hashArray = Array.from(new Uint8Array(hashBuffer));
    const hashHex = hashArray
        .map((b) => b.toString(16).padStart(2, '0'))
        .join('');
    return hashHex;
}
function isValidHttpUrl(str) {
    const pattern = new RegExp('^(https?:\\/\\/)?' + // protocol
        '((([a-z\\d]([a-z\\d-]*[a-z\\d])*)\\.)+[a-z]{2,}|' + // domain name
        '((\\d{1,3}\\.){3}\\d{1,3}))' + // OR ip (v4) address
        '(\\:\\d+)?(\\/[-a-z\\d%_.~+]*)*' + // port and path
        '(\\?[;&a-z\\d%_.~+=-]*)?' + // query string
        '(\\#[-a-z\\d_]*)?$', // fragment locator
    'i');
    return pattern.test(str);
}
function apply(ctx) {
    ctx.on('message-created', async (session) => {
        const input = session.content.trim();
        if (input.startsWith(`https://github.com/`) && isValidHttpUrl(input)) {
            const parts = input.split('/');
            const owner = parts[3];
            const repository = parts[4];
            if (owner && repository) {
                const originalUrl = `https://github.com/${owner}/${repository}`;
                const hashHex = await digest(originalUrl);
                await session.send(koishi_1.h.image(`https://opengraph.githubassets.com/${hashHex}/${owner}/${repository}`));
            }
            return;
        }
        if (/^[A-Za-z0-9_-]+\/[A-Za-z0-9_.-]+$/.test(input)) {
            const originalUrl = `https://github.com/${input}`;
            const hashHex = await digest(originalUrl);
            return await session.send(koishi_1.h.image(`https://opengraph.githubassets.com/${hashHex}/${input}`));
        }
    });
}
exports.apply = apply;
